@@ -6,9 +6,7 @@ from pathlib import Path
 
 import httpx
 
-from yappa.settings import DEFAULT_CONFIG_FILENAME
-from yappa.utils import load_yaml
-from .handle_utils import (set_access_token, update_django_pg_connection)
+from .common import (DEFAULT_CONFIG_FILENAME, load_yaml, set_access_token)
 
 logger = logging.getLogger(__name__)
 
@@ -77,9 +75,5 @@ def handle(event, context):
     set_access_token()
     if not event:
         raise ValueError("Got empty event")
-
-    if config["django_settings_module"]:
-        update_django_pg_connection(context.token["access_token"])
-        # TODO check if it's necessary to update db settings
     response = call_app(app, event)
     return patch_response(response)
